@@ -12,21 +12,20 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import json
 import logging
 from http import HTTPStatus
 from typing import Any, Optional
 
-import json
 import pydantic
 import pydantic.schema
 import requests
 
-from openworld.sdk.core.client.auth_client import _AuthClient
+from openworld.sdk.core.client.auth_client import AuthClient
 from openworld.sdk.core.configuration.client_config import ClientConfig
 from openworld.sdk.core.constant import header as header_constant
 from openworld.sdk.core.constant import log as log_constant
 from openworld.sdk.core.constant.constant import OK_STATUS_CODES_RANGE
-from openworld.sdk.core.model.authentication import HttpBearerAuth
 from openworld.sdk.core.model.error import Error
 from openworld.sdk.core.model.exception import service as service_exception
 from openworld.sdk.core.util import log as log_util
@@ -35,17 +34,18 @@ LOG = logging.getLogger(__name__)
 
 
 class ApiClient:
-    def __init__(self, config: ClientConfig):
+    def __init__(self, config: ClientConfig, auth_client_cls):
         r"""Sends requests to API.
 
         :param config: Client Configuration Wrapper
         """
-        self.__auth_client: _AuthClient = _AuthClient(
+        self.__auth_client: AuthClient = auth_client_cls(
             credentials=config.auth_config.credentials,
             auth_endpoint=config.auth_config.auth_endpoint,
         )
 
         self.endpoint = config.endpoint
+        self.request_timeout = config.request_timeout
 
     @staticmethod
     def __build_response(response: requests.Response, response_models: list[pydantic.BaseModel]):
@@ -72,8 +72,8 @@ class ApiClient:
         method: str,
         url: str,
         body: pydantic.BaseModel,
-        headers: dict = dict(), # noqa
-        response_models: Optional[list[Any]] = [None], # noqa
+        headers: dict = dict(),  # noqa
+        response_models: Optional[list[Any]] = [None],  # noqa
     ) -> Any:
         r"""Sends HTTP request to API.
 
@@ -88,7 +88,6 @@ class ApiClient:
         """
         self.__auth_client.refresh_token()
         request_headers = ApiClient.__prepare_request_headers(headers)
-        auth_bearer = HttpBearerAuth(access_token=self.__auth_client.access_token)
         request_body = dict()
 
         if not body:
@@ -96,7 +95,8 @@ class ApiClient:
                 method=method.upper(),
                 url=str(url),
                 headers=request_headers,
-                auth=auth_bearer,
+                auth=self.__auth_client.auth_header,
+                timeout=self.request_timeout,
             )
         else:
             request_body = body.json(exclude_none=True, exclude_unset=True)
@@ -105,7 +105,8 @@ class ApiClient:
                 url=url,
                 headers=request_headers,
                 data=request_body,
-                auth=auth_bearer,
+                auth=self.__auth_client.auth_header,
+                timeout=self.request_timeout,
             )
 
         request_log_message = log_util.request_log(
