@@ -33,3 +33,11 @@ USER_AGENT: str = "User-agent"
 OPENWORLD_SDK_PYTHON: str = "open-world-sdk-python/"
 
 API_REQUEST: dict = {CONTENT_TYPE: JSON_CONTENT_TYPE, ACCEPT: JSON_CONTENT_TYPE}
+
+EAN: str = "EAN"
+
+API_KEY: str = "APIKey"
+
+SIGNATURE: str = "Signature"
+
+TIMESTAMP: str = "timestamp"
